@@ -5,7 +5,7 @@ use {
         file_sum::FileSum,
         git::LineGitStatus,
     },
-    lazy_regex::regex,
+    lazy_regex::regex_captures,
     std::{
         cmp::{self, Ord, Ordering, PartialOrd},
         fs,
@@ -42,17 +42,13 @@ pub struct TreeLine {
 impl TreeLine {
 
     pub fn double_extension_from_name(name: &str) -> Option<&str> {
-        regex!(r"\.([^.]+\.[^.]+)")
-            .captures(&name)
-            .and_then(|c| c.get(1))
-            .map(|e| e.as_str())
+        regex_captures!(r"\.([^.]+\.[^.]+)", name)
+            .map(|(_, de)| de)
     }
 
     pub fn extension_from_name(name: &str) -> Option<&str> {
-        regex!(r"\.([^.]+)$")
-            .captures(&name)
-            .and_then(|c| c.get(1))
-            .map(|e| e.as_str())
+        regex_captures!(r"\.([^.]+)$", name)
+            .map(|(_, ext)| ext)
     }
 
     pub fn is_selectable(&self) -> bool {
@@ -106,6 +102,10 @@ impl TreeLine {
         Mode::from(self.metadata.mode())
     }
     #[cfg(unix)]
+    pub fn device_id(&self) -> lfs_core::DeviceId {
+        self.metadata.dev().into()
+    }
+    #[cfg(unix)]
     pub fn mount(&self) -> Option<lfs_core::Mount> {
         use crate::filesystems::*;
         let mut mount_list = MOUNTS.lock().unwrap();
