@@ -1,7 +1,7 @@
 use {
     super::*,
     crate::{
-        app::{Selection, SelInfo, SelectionType},
+        app::*,
         errors::ConfError,
         keys,
         path::{self, PathAnchor},
@@ -54,6 +54,14 @@ pub struct Verb {
     /// whether we need to have a secondary panel for execution
     /// (which is the case when the execution pattern has {other-panel-file})
     pub needs_another_panel: bool,
+
+    /// if true (default) verbs are directly executed when
+    /// triggered with a keyboard shortcut
+    pub auto_exec: bool,
+
+    /// whether to show the verb in help screen
+    /// (if we show all input related actions, the doc is unusable)
+    pub show_in_doc: bool
 }
 
 impl Verb {
@@ -68,18 +76,21 @@ impl Verb {
         if let Some(ref invocation_parser) = invocation_parser {
             names.push(invocation_parser.name().to_string());
         }
-        let (needs_selection, needs_another_panel) = match &execution {
+        let (
+            needs_selection,
+            needs_another_panel,
+        ) = match &execution {
             VerbExecution::Internal(ie) => (
                 ie.needs_selection(),
                 false,
             ),
             VerbExecution::External(ee) => (
                 ee.exec_pattern.has_selection_group(),
-                ee.exec_pattern.has_other_panel_group()
+                ee.exec_pattern.has_other_panel_group(),
             ),
             VerbExecution::Sequence(se) => (
                 se.sequence.has_selection_group(),
-                se.sequence.has_other_panel_group()
+                se.sequence.has_other_panel_group(),
             )
         };
         Ok(Self {
@@ -92,6 +103,8 @@ impl Verb {
             selection_condition: SelectionType::Any,
             needs_selection,
             needs_another_panel,
+            auto_exec: true,
+            show_in_doc: true,
         })
     }
     fn update_key_desc(&mut self) {
@@ -131,6 +144,10 @@ impl Verb {
             modifiers: KeyModifiers::NONE,
         })
     }
+    pub fn no_doc(mut self) -> Self {
+        self.show_in_doc = false;
+        self
+    }
     pub fn with_description(mut self, description: &str) -> Self {
         self.description = VerbDescription::from_text(description.to_string());
         self
@@ -147,6 +164,10 @@ impl Verb {
         self.needs_another_panel = true;
         self
     }
+    pub fn with_auto_exec(mut self, b: bool) -> Self {
+        self.auto_exec = b;
+        self
+    }
 
     /// Assuming the verb has been matched, check whether the arguments
     /// are OK according to the regex. Return none when there's no problem
@@ -198,7 +219,7 @@ impl Verb {
     pub fn get_status_markdown(
         &self,
         sel_info: SelInfo<'_>,
-        other_path: &Option<PathBuf>,
+        app_state: &AppState,
         invocation: &VerbInvocation,
     ) -> String {
         let name = self.names.get(0).unwrap_or(&invocation.name);
@@ -210,7 +231,7 @@ impl Verb {
         // thus I hardcode the test here.
         if let VerbExecution::Internal(internal_exec) = &self.execution {
             if internal_exec.internal == Internal::focus {
-                if let Some(sel) = sel_info.as_one_sel() {
+                if let Some(sel) = sel_info.one_sel() {
                     let arg = invocation.args.as_ref().or_else(|| internal_exec.arg.as_ref());
                     let pb;
                     let arg_path = if let Some(arg) = arg {
@@ -224,14 +245,13 @@ impl Verb {
                     return "You can't focus without selection".to_string();
                 }
             }
-            // TODO check that before
         }
 
         let builder = || {
-            ExecutionStringBuilder::from_invocation(
+            ExecutionStringBuilder::with_invocation(
                 &self.invocation_parser,
                 sel_info,
-                other_path,
+                app_state,
                 &invocation.args,
             )
         };
